From: tip-bot for Len Brown <tipbot@zytor.com>
To: linux-tip-commits@vger.kernel.org
Cc: linux-kernel@vger.kernel.org, rui.zhang@intel.com,
tglx@linutronix.de, hpa@zytor.com, mingo@kernel.org,
len.brown@intel.com, peterz@infradead.org
Subject: [tip:x86/topology] hwmon/coretemp: Cosmetic: Rename internal variables to zones from packages
Date: Thu, 23 May 2019 02:34:07 -0700 [thread overview]
Message-ID: <tip-835896a59b9577d0bc2131e027c37bdde5b979af@git.kernel.org> (raw)
In-Reply-To: <facecfd3525d55c2051f63a7ec709aeb03cc1dc1.1557769318.git.len.brown@intel.com>
Commit-ID: 835896a59b9577d0bc2131e027c37bdde5b979af
Gitweb: https://git.kernel.org/tip/835896a59b9577d0bc2131e027c37bdde5b979af
Author: Len Brown <len.brown@intel.com>
AuthorDate: Mon, 13 May 2019 13:59:01 -0400
Committer: Thomas Gleixner <tglx@linutronix.de>
CommitDate: Thu, 23 May 2019 10:08:36 +0200
hwmon/coretemp: Cosmetic: Rename internal variables to zones from packages
Syntax update only -- no logical or functional change.
In response to the new multi-die/package changes, update variable names to
use the more generic thermal "zone" terminology, instead of "package", as
the zones can refer to either packages or die.
Signed-off-by: Len Brown <len.brown@intel.com>
Signed-off-by: Thomas Gleixner <tglx@linutronix.de>
Reviewed-by: Ingo Molnar <mingo@kernel.org>
Acked-by: Peter Zijlstra (Intel) <peterz@infradead.org>
Cc: Zhang Rui <rui.zhang@intel.com>
Link: https://lkml.kernel.org/r/facecfd3525d55c2051f63a7ec709aeb03cc1dc1.1557769318.git.len.brown@intel.com
---
drivers/hwmon/coretemp.c | 36 ++++++++++++++++++------------------
1 file changed, 18 insertions(+), 18 deletions(-)
diff --git a/drivers/hwmon/coretemp.c b/drivers/hwmon/coretemp.c
index c64ce32d3214..4ebed90d81aa 100644
--- a/drivers/hwmon/coretemp.c
+++ b/drivers/hwmon/coretemp.c
@@ -109,10 +109,10 @@ struct platform_data {
struct device_attribute name_attr;
};
-/* Keep track of how many package pointers we allocated in init() */
-static int max_packages __read_mostly;
-/* Array of package pointers. Serialized by cpu hotplug lock */
-static struct platform_device **pkg_devices;
+/* Keep track of how many zone pointers we allocated in init() */
+static int max_zones __read_mostly;
+/* Array of zone pointers. Serialized by cpu hotplug lock */
+static struct platform_device **zone_devices;
static ssize_t show_label(struct device *dev,
struct device_attribute *devattr, char *buf)
@@ -435,10 +435,10 @@ static int chk_ucode_version(unsigned int cpu)
static struct platform_device *coretemp_get_pdev(unsigned int cpu)
{
- int pkgid = topology_logical_die_id(cpu);
+ int id = topology_logical_die_id(cpu);
- if (pkgid >= 0 && pkgid < max_packages)
- return pkg_devices[pkgid];
+ if (id >= 0 && id < max_zones)
+ return zone_devices[id];
return NULL;
}
@@ -544,7 +544,7 @@ static int coretemp_probe(struct platform_device *pdev)
struct device *dev = &pdev->dev;
struct platform_data *pdata;
/* Initialize the per-package data structures */
pdata = devm_kzalloc(dev, sizeof(struct platform_data), GFP_KERNEL);
if (!pdata)
return -ENOMEM;
@@ -579,13 +579,13 @@ static struct platform_driver coretemp_driver = {
static struct platform_device *coretemp_device_add(unsigned int cpu)
{
- int err, pkgid = topology_logical_die_id(cpu);
+ int err, zoneid = topology_logical_die_id(cpu);
struct platform_device *pdev;
- if (pkgid < 0)
+ if (zoneid < 0)
return ERR_PTR(-ENOMEM);
- pdev = platform_device_alloc(DRVNAME, pkgid);
+ pdev = platform_device_alloc(DRVNAME, zoneid);
if (!pdev)
return ERR_PTR(-ENOMEM);
@@ -595,7 +595,7 @@ static struct platform_device *coretemp_device_add(unsigned int cpu)
return ERR_PTR(err);
}
- pkg_devices[pkgid] = pdev;
+ zone_devices[zoneid] = pdev;
return pdev;
}
@@ -703,7 +703,7 @@ static int coretemp_cpu_offline(unsigned int cpu)
* the rest.
*/
if (cpumask_empty(&pd->cpumask)) {
- pkg_devices[topology_logical_die_id(cpu)] = NULL;
+ zone_devices[topology_logical_die_id(cpu)] = NULL;
platform_device_unregister(pdev);
return 0;
}
@@ -741,10 +741,10 @@ static int __init coretemp_init(void)
if (!x86_match_cpu(coretemp_ids))
return -ENODEV;
- max_packages = topology_max_packages() * topology_max_die_per_package();
- pkg_devices = kcalloc(max_packages, sizeof(struct platform_device *),
+ max_zones = topology_max_packages() * topology_max_die_per_package();
+ zone_devices = kcalloc(max_zones, sizeof(struct platform_device *),
GFP_KERNEL);
- if (!pkg_devices)
+ if (!zone_devices)
return -ENOMEM;
err = platform_driver_register(&coretemp_driver);
@@ -760,7 +760,7 @@ static int __init coretemp_init(void)
outdrv:
platform_driver_unregister(&coretemp_driver);
- kfree(pkg_devices);
+ kfree(zone_devices);
return err;
}
module_init(coretemp_init)
@@ -769,7 +769,7 @@ static void __exit coretemp_exit(void)
{
cpuhp_remove_state(coretemp_hp_online);
platform_driver_unregister(&coretemp_driver);
- kfree(pkg_devices);
+ kfree(zone_devices);
}
module_exit(coretemp_exit)
next prev parent reply other threads:[~2019-05-23 9:34 UTC|newest]
Thread overview: 42+ messages / expand[flat|nested] mbox.gz Atom feed top
2019-05-13 17:58 [PATCH 0/19] v6 multi-die/package topology support Len Brown
2019-05-13 17:58 ` [PATCH 01/19] x86 topology: Add CPUID.1F multi-die/package support Len Brown
2019-05-13 17:58 ` [PATCH 02/19] x86 topology: Create topology_max_die_per_package() Len Brown
2019-05-23 9:23 ` [tip:x86/topology] x86/topology: " tip-bot for Len Brown
2019-05-13 17:58 ` [PATCH 03/19] cpu topology: Export die_id Len Brown
2019-05-23 9:24 ` [tip:x86/topology] cpu/topology: " tip-bot for Len Brown
2019-05-13 17:58 ` [PATCH 04/19] x86 topology: Define topology_die_id() Len Brown
2019-05-23 9:24 ` [tip:x86/topology] x86/topology: " tip-bot for Len Brown
2019-05-13 17:58 ` [PATCH 05/19] x86 topology: Define topology_logical_die_id() Len Brown
2019-05-23 9:25 ` [tip:x86/topology] x86/topology: " tip-bot for Len Brown
2019-05-13 17:58 ` [PATCH 06/19] powercap/intel_rapl: Simplify rapl_find_package() Len Brown
2019-05-23 9:26 ` [tip:x86/topology] " tip-bot for Zhang Rui
2019-05-13 17:58 ` [PATCH 07/19] powercap/intel_rapl: Support multi-die/package Len Brown
2019-05-23 9:26 ` [tip:x86/topology] " tip-bot for Zhang Rui
2019-05-13 17:58 ` [PATCH 08/19] thermal/x86_pkg_temp_thermal: " Len Brown
2019-05-23 9:27 ` [tip:x86/topology] " tip-bot for Zhang Rui
2019-05-13 17:58 ` [PATCH 09/19] powercap/intel_rapl: Update RAPL domain name and debug messages Len Brown
2019-05-23 9:28 ` [tip:x86/topology] " tip-bot for Zhang Rui
2019-05-13 17:58 ` [PATCH 10/19] hwmon/coretemp: Support multi-die/package Len Brown
2019-05-23 9:29 ` [tip:x86/topology] " tip-bot for Zhang Rui
2019-05-13 17:58 ` [PATCH 11/19] topology: Create package_cpus sysfs attribute Len Brown
2019-05-23 9:29 ` [tip:x86/topology] " tip-bot for Len Brown
2019-05-13 17:58 ` [PATCH 12/19] topology: Create core_cpus and die_cpus sysfs attributes Len Brown
2019-05-23 9:30 ` [tip:x86/topology] " tip-bot for Len Brown
2019-05-13 17:58 ` [PATCH 13/19] perf/x86/intel/uncore: Support multi-die/package Len Brown
2019-05-23 9:31 ` [tip:x86/topology] " tip-bot for Kan Liang
2019-05-13 17:58 ` [PATCH 14/19] perf/x86/intel/rapl: " Len Brown
2019-05-23 9:31 ` [tip:x86/topology] " tip-bot for Kan Liang
2019-05-13 17:58 ` [PATCH 15/19] perf/x86/intel/cstate: " Len Brown
2019-05-23 9:32 ` [tip:x86/topology] " tip-bot for Kan Liang
2019-05-13 17:59 ` [PATCH 16/19] thermal/x86_pkg_temp_thermal: Cosmetic: Rename internal variables to zones from packages Len Brown
2019-05-23 9:33 ` [tip:x86/topology] " tip-bot for Len Brown
2019-05-13 17:59 ` [PATCH 17/19] hwmon/coretemp: " Len Brown
2019-05-23 9:34 ` tip-bot for Len Brown [this message]
2019-05-13 17:59 ` [PATCH 18/19] perf/x86/intel/uncore: Cosmetic renames in response to multi-die/pkg support Len Brown
2019-05-23 9:34 ` [tip:x86/topology] " tip-bot for Kan Liang
2019-05-13 17:59 ` [PATCH 19/19] perf/x86/intel/rapl: Cosmetic rename internal variables " Len Brown
2019-05-23 9:35 ` [tip:x86/topology] " tip-bot for Kan Liang
2019-05-23 9:22 ` [tip:x86/topology] x86/topology: Add CPUID.1F multi-die/package support tip-bot for Len Brown
2019-05-15 8:55 ` [PATCH 0/19] v6 multi-die/package topology support Peter Zijlstra
2019-05-15 16:38 ` Ingo Molnar
2019-05-22 20:44 ` Ingo Molnar
Reply instructions:
You may reply publicly to this message via plain-text email
using any one of the following methods:
* Save the following mbox file, import it into your mail client,
and reply-to-all from there: mbox
Avoid top-posting and favor interleaved quoting:
https://en.wikipedia.org/wiki/Posting_style#Interleaved_style
* Reply using the --to, --cc, and --in-reply-to
switches of git-send-email(1):
git send-email \
--in-reply-to=tip-835896a59b9577d0bc2131e027c37bdde5b979af@git.kernel.org \
--to=tipbot@zytor.com \
--cc=hpa@zytor.com \
--cc=len.brown@intel.com \
--cc=linux-kernel@vger.kernel.org \
--cc=linux-tip-commits@vger.kernel.org \
--cc=mingo@kernel.org \
--cc=peterz@infradead.org \
--cc=rui.zhang@intel.com \
--cc=tglx@linutronix.de \
/path/to/YOUR_REPLY
https://kernel.org/pub/software/scm/git/docs/git-send-email.html
* If your mail client supports setting the In-Reply-To header
@@ -544,7 +544,7 @@ static int coretemp_probe(struct platform_device *pdev)
struct device *dev = &pdev->dev;
struct platform_data *pdata;
- /* Initialize the per-package data structures */
+ /* Initialize the per-zone data structures */
pdata = devm_kzalloc(dev, sizeof(struct platform_data), GFP_KERNEL);
if (!pdata)
via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line
before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox
Powered by JetHome